Trait css_purify::DeduplicatedSelectorsExt
[−]
[src]
pub trait DeduplicatedSelectorsExt {
fn remove_unmatched_selectors<HtmlDocumentOrNode: Selectable>(
&mut self,
html_document_and_nodes: &[&HtmlDocumentOrNode]
);
}Extensions to DeduplicatedSelectors.
Required Methods
fn remove_unmatched_selectors<HtmlDocumentOrNode: Selectable>(
&mut self,
html_document_and_nodes: &[&HtmlDocumentOrNode]
)
&mut self,
html_document_and_nodes: &[&HtmlDocumentOrNode]
)
Removes all selectors that don't match in the set of html_document_and_nodes.
As a result, the associated StyleRule for these selectors may no longer be necessary if there are no matching selectors at all.
Implementations on Foreign Types
impl DeduplicatedSelectorsExt for DeduplicatedSelectors[src]
fn remove_unmatched_selectors<HtmlDocumentOrNode: Selectable>(
&mut self,
html_document_and_nodes: &[&HtmlDocumentOrNode]
)[src]
&mut self,
html_document_and_nodes: &[&HtmlDocumentOrNode]
)